Struct ZwpTabletSeatV2
pub struct ZwpTabletSeatV2 { /* private fields */ }wayland and Linux only.Expand description
controller object for graphic tablet devices of a seat
An object that provides access to the graphics tablets available on this seat. After binding to this interface, the compositor sends a set of zwp_tablet_seat_v2.tablet_added and zwp_tablet_seat_v2.tool_added events.
See also the Request enum for this interface.
Implementations
impl ZwpTabletSeatV2
impl ZwpTabletSeatV2
pub fn tablet_added(&self, id: &ZwpTabletV2)
pub fn tablet_added(&self, id: &ZwpTabletV2)
new device notification
This event is sent whenever a new tablet becomes available on this seat. This event only provides the object id of the tablet, any static information about the tablet (device name, vid/pid, etc.) is sent through the zwp_tablet_v2 interface.
pub fn tool_added(&self, id: &ZwpTabletToolV2)
pub fn tool_added(&self, id: &ZwpTabletToolV2)
a new tool has been used with a tablet
This event is sent whenever a tool that has not previously been used with a tablet comes into use. This event only provides the object id of the tool; any static information about the tool (capabilities, type, etc.) is sent through the zwp_tablet_tool_v2 interface.
pub fn pad_added(&self, id: &ZwpTabletPadV2)
pub fn pad_added(&self, id: &ZwpTabletPadV2)
new pad notification
This event is sent whenever a new pad is known to the system. Typically, pads are physically attached to tablets and a pad_added event is sent immediately after the zwp_tablet_seat_v2.tablet_added. However, some standalone pad devices logically attach to tablets at runtime, and the client must wait for zwp_tablet_pad_v2.enter to know the tablet a pad is attached to.
This event only provides the object id of the pad. All further features (buttons, strips, rings) are sent through the zwp_tablet_pad_v2 interface.